(sec_citation)=

# Citing tsinfer

If you use `tsinfer` in your work, please cite the
[2019 Nature Genetics paper](<https://doi.org/10.1038/s41588-019-0483-y>):

> Jerome Kelleher, Yan Wong, Anthony W. Wohns, 
> Chaimaa Fadil, Patrick K. Albers & Gil McVean (2019) 
> *Inferring whole-genome histories in large population datasets*,
> Nature Genetics, Volume 51, 1330–1338. https://doi.org/10.1038/s41588-019-0483-y

Bibtex record:

```bibtex

@article{Kelleher2019,
  doi = {10.1038/s41588-019-0483-y},
  url = {https://doi.org/10.1038/s41588-019-0483-y},
  year = {2019},
  month = sep,
  publisher = {Springer Science and Business Media {LLC}},
  volume = {51},
  number = {9},
  pages = {1330--1338},
  author = {Jerome Kelleher and Yan Wong and Anthony W. Wohns and Chaimaa Fadil and Patrick K. Albers and Gil McVean},
  title = {Inferring whole-genome histories in large population datasets},
  journal = {Nature Genetics}
}